## Version 3.0.2 (2025/10/03)


### Pull Requests Merged

* [PR 541](https://github.com/andfoy/pywinpty/pull/541) - Add README section in pyproject.toml, by [@andfoy](https://github.com/andfoy)

In this release 1 pull request was closed.


## Version 3.0.1 (2025/10/03)


### Pull Requests Merged

* [PR 540](https://github.com/andfoy/pywinpty/pull/540) - Update Rust dependencies ahead of v3.0.1, by [@andfoy](https://github.com/andfoy)
* [PR 539](https://github.com/andfoy/pywinpty/pull/539) - Fix typos discovered by codespell, by [@cclauss](https://github.com/cclauss)
* [PR 538](https://github.com/andfoy/pywinpty/pull/538) - Remove deprecated actions-rs/toolchain, by [@cclauss](https://github.com/cclauss)
* [PR 535](https://github.com/andfoy/pywinpty/pull/535) - Support Python 3.14(t), by [@ngoldbaum](https://github.com/ngoldbaum)
* [PR 534](https://github.com/andfoy/pywinpty/pull/534) - Bump serde_json from 1.0.142 to 1.0.145, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 533](https://github.com/andfoy/pywinpty/pull/533) - Update build.rs, by [@ImmortalEmperor](https://github.com/ImmortalEmperor)
* [PR 520](https://github.com/andfoy/pywinpty/pull/520) - Bump actions/checkout from 4 to 5, by [@dependabot[bot]](https://github.com/apps/dependabot)

In this release 7 pull requests were closed.


## Version 3.0.0 (2025/08/12)


### Pull Requests Merged

* [PR 517](https://github.com/andfoy/pywinpty/pull/517) - Solve type issues, by [@XY0797](https://github.com/XY0797)
* [PR 515](https://github.com/andfoy/pywinpty/pull/515) - Update winpty-rs to v1.0.3, by [@andfoy](https://github.com/andfoy)

In this release 2 pull requests were closed.


## Version 2.0.15 (2025/02/03)


### Pull Requests Merged

* [PR 492](https://github.com/andfoy/pywinpty/pull/492) - Add version to pyproject.toml, by [@finnagin](https://github.com/finnagin)
* [PR 488](https://github.com/andfoy/pywinpty/pull/488) - Bump pyo3 from 0.22.5 to 0.23.4, by [@dependabot[bot]](https://github.com/apps/dependabot) ([491](https://github.com/andfoy/pywinpty/issues/491), [](https://github.com/<code>/issues/))

In this release 2 pull requests were closed.


## Version 2.0.14 (2024/10/17)


### Pull Requests Merged

* [PR 453](https://github.com/andfoy/pywinpty/pull/453) - Update PyO3 to 0.22.3 and winpty-rs to 0.4.0, by [@andfoy](https://github.com/andfoy)
* [PR 452](https://github.com/andfoy/pywinpty/pull/452) - Add support for Python 3.13, by [@andfoy](https://github.com/andfoy) ([451](https://github.com/andfoy/pywinpty/issues/451))

In this release 2 pull requests were closed.


## Version 2.0.13 (2024/02/26)


### Pull Requests Merged

* [PR 399](https://github.com/andfoy/pywinpty/pull/399) - Bump target-lexicon from 0.12.13 to 0.12.14, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 398](https://github.com/andfoy/pywinpty/pull/398) - Bump winpty-rs from 0.3.14 to 0.3.15, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 397](https://github.com/andfoy/pywinpty/pull/397) - Bump syn from 2.0.43 to 2.0.50, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 396](https://github.com/andfoy/pywinpty/pull/396) - Remove pytest-lazy-fixture from test dependencies, by [@andfoy](https://github.com/andfoy)
* [PR 395](https://github.com/andfoy/pywinpty/pull/395) - Bump rustix from 0.38.30 to 0.38.31, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 393](https://github.com/andfoy/pywinpty/pull/393) - Bump once_cell from 1.18.0 to 1.19.0, by [@dependabot[bot]](https://github.com/apps/dependabot) ([](https://github.com/CI</issues/), [](https://github.com/CI</issues/), [](https://github.com/CI</issues/))
* [PR 392](https://github.com/andfoy/pywinpty/pull/392) - Bump smallvec from 1.11.1 to 1.13.1, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 390](https://github.com/andfoy/pywinpty/pull/390) - Bump parking_lot_core from 0.9.8 to 0.9.9, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 388](https://github.com/andfoy/pywinpty/pull/388) - Bump target-lexicon from 0.12.11 to 0.12.13, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 387](https://github.com/andfoy/pywinpty/pull/387) - Bump winpty-rs from 0.3.13 to 0.3.14, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 386](https://github.com/andfoy/pywinpty/pull/386) - Bump pyo3 from 0.19.2 to 0.20.2, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 385](https://github.com/andfoy/pywinpty/pull/385) - Bump proc-macro2 from 1.0.68 to 1.0.78, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 384](https://github.com/andfoy/pywinpty/pull/384) - Bump linux-raw-sys from 0.4.8 to 0.4.13, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 375](https://github.com/andfoy/pywinpty/pull/375) - Bump conda-incubator/setup-miniconda from 2 to 3, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 374](https://github.com/andfoy/pywinpty/pull/374) - Bump errno from 0.3.4 to 0.3.8, by [@dependabot[bot]](https://github.com/apps/dependabot) ([](https://github.com/<code>to_string()</issues/))
* [PR 369](https://github.com/andfoy/pywinpty/pull/369) - Bump lock_api from 0.4.10 to 0.4.11, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 368](https://github.com/andfoy/pywinpty/pull/368) - Bump rustix from 0.38.17 to 0.38.21, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 362](https://github.com/andfoy/pywinpty/pull/362) - Bump num-traits from 0.2.16 to 0.2.17, by [@dependabot[bot]](https://github.com/apps/dependabot)

In this release 18 pull requests were closed.


## Version 2.0.12 (2023/10/06)


### Pull Requests Merged

* [PR 360](https://github.com/andfoy/pywinpty/pull/360) - Update core dependencies, by [@andfoy](https://github.com/andfoy) ([345](https://github.com/andfoy/pywinpty/issues/345))
* [PR 359](https://github.com/andfoy/pywinpty/pull/359) - Enable Python 3.12 support, by [@albertopasqualetto](https://github.com/albertopasqualetto)
* [PR 358](https://github.com/andfoy/pywinpty/pull/358) - Bump actions/checkout from 3 to 4, by [@dependabot[bot]](https://github.com/apps/dependabot)

In this release 3 pull requests were closed.


## Version 2.0.11 (2023/07/14)


### Pull Requests Merged

* [PR 333](https://github.com/andfoy/pywinpty/pull/333) - Update winpty-rs and PyO3 to the latest versions, by [@andfoy](https://github.com/andfoy)
* [PR 332](https://github.com/andfoy/pywinpty/pull/332) - Fix an encoding issue in sendcontrol, by [@ddddhm1234](https://github.com/ddddhm1234)

In this release 2 pull requests were closed.


## Version 2.0.10 (2023/01/02)

### Issues Closed

* [Issue 319](https://github.com/andfoy/pywinpty/issues/319) - Release v2.0.10

In this release 1 issue was closed.

### Pull Requests Merged

* [PR 318](https://github.com/andfoy/pywinpty/pull/318) - Bump winpty-rs from 0.3.9 to 0.3.11, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 317](https://github.com/andfoy/pywinpty/pull/317) - Bump parking_lot_core from 0.9.3 to 0.9.5, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 316](https://github.com/andfoy/pywinpty/pull/316) - Bump quote from 1.0.21 to 1.0.23, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 315](https://github.com/andfoy/pywinpty/pull/315) - Bump target-lexicon from 0.12.4 to 0.12.5, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 314](https://github.com/andfoy/pywinpty/pull/314) - Bump unindent from 0.1.10 to 0.1.11, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 313](https://github.com/andfoy/pywinpty/pull/313) - Bump indoc from 1.0.7 to 1.0.8, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 311](https://github.com/andfoy/pywinpty/pull/311) - Bump libc from 0.2.137 to 0.2.139, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 310](https://github.com/andfoy/pywinpty/pull/310) - Bump once_cell from 1.15.0 to 1.17.0, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 309](https://github.com/andfoy/pywinpty/pull/309) - Bump proc-macro2 from 1.0.47 to 1.0.49, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 308](https://github.com/andfoy/pywinpty/pull/308) - Bump syn from 1.0.101 to 1.0.107, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 307](https://github.com/andfoy/pywinpty/pull/307) - Bump unicode-ident from 1.0.4 to 1.0.6, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 301](https://github.com/andfoy/pywinpty/pull/301) - Bump smallvec from 1.9.0 to 1.10.0, by [@dependabot[bot]](https://github.com/apps/dependabot)

In this release 12 pull requests were closed.


## Version 2.0.9 (2022/10/26)


### Pull Requests Merged

* [PR 296](https://github.com/andfoy/pywinpty/pull/296) - Enable Python 3.11 support, by [@andfoy](https://github.com/andfoy) ([295](https://github.com/andfoy/pywinpty/issues/295))
* [PR 294](https://github.com/andfoy/pywinpty/pull/294) - Bump libc from 0.2.133 to 0.2.137, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 292](https://github.com/andfoy/pywinpty/pull/292) - Bump proc-macro2 from 1.0.43 to 1.0.47, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 288](https://github.com/andfoy/pywinpty/pull/288) - Bump syn from 1.0.100 to 1.0.101, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 286](https://github.com/andfoy/pywinpty/pull/286) - Bump once_cell from 1.14.0 to 1.15.0, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 285](https://github.com/andfoy/pywinpty/pull/285) - Bump winpty-rs from 0.3.8 to 0.3.9, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 283](https://github.com/andfoy/pywinpty/pull/283) - Bump libc from 0.2.132 to 0.2.133, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 282](https://github.com/andfoy/pywinpty/pull/282) - Bump syn from 1.0.99 to 1.0.100, by [@dependabot[bot]](https://github.com/apps/dependabot)

In this release 8 pull requests were closed.


## Version 2.0.8 (2022/09/15)

### Issues Closed

* [Issue 281](https://github.com/andfoy/pywinpty/issues/281) - Release v2.0.8

In this release 1 issue was closed.

### Pull Requests Merged

* [PR 280](https://github.com/andfoy/pywinpty/pull/280) - Bump unicode-ident from 1.0.3 to 1.0.4, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 279](https://github.com/andfoy/pywinpty/pull/279) - Bump once_cell from 1.13.1 to 1.14.0, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 278](https://github.com/andfoy/pywinpty/pull/278) - Bump which from 4.2.5 to 4.3.0, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 277](https://github.com/andfoy/pywinpty/pull/277) - Bump pyo3 from 0.17.0 to 0.17.1, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 276](https://github.com/andfoy/pywinpty/pull/276) - Bump lock_api from 0.4.7 to 0.4.8, by [@dependabot[bot]](https://github.com/apps/dependabot) ([](https://github.com/bounds</issues/))
* [PR 273](https://github.com/andfoy/pywinpty/pull/273) - Bump pyo3 from 0.16.5 to 0.17.0, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 272](https://github.com/andfoy/pywinpty/pull/272) - Bump either from 1.7.0 to 1.8.0, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 271](https://github.com/andfoy/pywinpty/pull/271) - Bump libc from 0.2.127 to 0.2.132, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 270](https://github.com/andfoy/pywinpty/pull/270) - Bump once_cell from 1.13.0 to 1.13.1, by [@dependabot[bot]](https://github.com/apps/dependabot)

In this release 9 pull requests were closed.


## Version 2.0.7 (2022/08/05)

### Issues Closed

* [Issue 266](https://github.com/andfoy/pywinpty/issues/266) - Release v2.0.7

In this release 1 issue was closed.

### Pull Requests Merged

* [PR 265](https://github.com/andfoy/pywinpty/pull/265) - Bump unicode-ident from 1.0.2 to 1.0.3, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 264](https://github.com/andfoy/pywinpty/pull/264) - Bump quote from 1.0.20 to 1.0.21, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 263](https://github.com/andfoy/pywinpty/pull/263) - Bump libc from 0.2.126 to 0.2.127, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 262](https://github.com/andfoy/pywinpty/pull/262) - Bump syn from 1.0.98 to 1.0.99, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 261](https://github.com/andfoy/pywinpty/pull/261) - Bump proc-macro2 from 1.0.42 to 1.0.43, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 260](https://github.com/andfoy/pywinpty/pull/260) - Bump unindent from 0.1.9 to 0.1.10, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 259](https://github.com/andfoy/pywinpty/pull/259) - Bump indoc from 1.0.6 to 1.0.7, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 258](https://github.com/andfoy/pywinpty/pull/258) - Bump redox_syscall from 0.2.15 to 0.2.16, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 257](https://github.com/andfoy/pywinpty/pull/257) - Bump proc-macro2 from 1.0.40 to 1.0.42, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 256](https://github.com/andfoy/pywinpty/pull/256) - Bump redox_syscall from 0.2.13 to 0.2.15, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 255](https://github.com/andfoy/pywinpty/pull/255) - Bump winpty-rs from 0.3.7 to 0.3.8, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 254](https://github.com/andfoy/pywinpty/pull/254) - Bump unicode-ident from 1.0.1 to 1.0.2, by [@dependabot[bot]](https://github.com/apps/dependabot)

In this release 12 pull requests were closed.


## Version 2.0.6 (2022/07/06)

### Issues Closed

* [Issue 253](https://github.com/spyder-ide/pywinpty/issues/253) - Release v2.0.6

In this release 1 issue was closed.

### Pull Requests Merged

* [PR 252](https://github.com/spyder-ide/pywinpty/pull/252) - PR: Update dependencies to latest versions, by [@andfoy](https://github.com/andfoy)
* [PR 233](https://github.com/spyder-ide/pywinpty/pull/233) - Bump pyo3 from 0.16.1 to 0.16.2, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 229](https://github.com/spyder-ide/pywinpty/pull/229) - Bump pyo3 from 0.16.0 to 0.16.1, by [@dependabot[bot]](https://github.com/apps/dependabot)

In this release 3 pull requests were closed.


## Version 2.0.5 (2022/03/04)

### Issues Closed

* [Issue 227](https://github.com/spyder-ide/pywinpty/issues/227) - Release v2.0.5

In this release 1 issue was closed.

### Pull Requests Merged

* [PR 226](https://github.com/spyder-ide/pywinpty/pull/226) - PR: Update winpty-rs to v0.3.6, by [@andfoy](https://github.com/andfoy)

In this release 1 pull request was closed.


## Version 2.0.4 (2022/03/03)

### Issues Closed

* [Issue 220](https://github.com/spyder-ide/pywinpty/issues/220) - Release v2.0.4
* [Issue 218](https://github.com/spyder-ide/pywinpty/issues/218) - Build failure on windows py3.6 ([PR 219](https://github.com/spyder-ide/pywinpty/pull/219) by [@andfoy](https://github.com/andfoy))
* [Issue 217](https://github.com/spyder-ide/pywinpty/issues/217) - ConPTY is not fully working in CI ([PR 219](https://github.com/spyder-ide/pywinpty/pull/219) by [@andfoy](https://github.com/andfoy))

In this release 3 issues were closed.

### Pull Requests Merged

* [PR 219](https://github.com/spyder-ide/pywinpty/pull/219) - PR: Update winpty-rs to v0.3.4, by [@andfoy](https://github.com/andfoy) ([218](https://github.com/spyder-ide/pywinpty/issues/218), [217](https://github.com/spyder-ide/pywinpty/issues/217))

In this release 1 pull request was closed.


## Version 2.0.3 (2022/03/02)

### Issues Closed

* [Issue 216](https://github.com/spyder-ide/pywinpty/issues/216) - Release v2.0.3

In this release 1 issue was closed.

### Pull Requests Merged

* [PR 215](https://github.com/spyder-ide/pywinpty/pull/215) - Bump actions/checkout from 2 to 3, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 214](https://github.com/spyder-ide/pywinpty/pull/214) - Update pyo3 requirement from 0.15.0 to 0.16.0, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 213](https://github.com/spyder-ide/pywinpty/pull/213) - PR: Add test that terminate causes EOFError, by [@blink1073](https://github.com/blink1073)

In this release 3 pull requests were closed.


## Version 2.0.2 (2022/02/03)

### Issues Closed

* [Issue 212](https://github.com/spyder-ide/pywinpty/issues/212) - Release v2.0.2

In this release 1 issue was closed.

### Pull Requests Merged

* [PR 211](https://github.com/spyder-ide/pywinpty/pull/211) - PR: Update winpty-rs version to v0.3.3, by [@andfoy](https://github.com/andfoy)

In this release 1 pull request was closed.


## Version 2.0.1 (2022/01/25)

### Issues Closed

* [Issue 209](https://github.com/spyder-ide/pywinpty/issues/209) - Release v2.0.1

In this release 1 issue was closed.

### Pull Requests Merged

* [PR 208](https://github.com/spyder-ide/pywinpty/pull/208) - PR: Remove .exe and .dll from gitignore when creating wheels, by [@andfoy](https://github.com/andfoy)

In this release 1 pull request was closed.


## Version 2.0.0 (2022/01/25)

### Issues Closed

* [Issue 207](https://github.com/spyder-ide/pywinpty/issues/207) - Release v2.0.0

In this release 1 issue was closed.

### Pull Requests Merged

* [PR 206](https://github.com/spyder-ide/pywinpty/pull/206) - PR: Move implementation to use winpty-rs, by [@andfoy](https://github.com/andfoy)

In this release 1 pull request was closed.


## Version 1.1.6 (2021-11-15)

### Issues Closed

* [Issue 201](https://github.com/spyder-ide/pywinpty/issues/201) - Release v1.1.6

In this release 1 issue was closed.

### Pull Requests Merged

* [PR 199](https://github.com/spyder-ide/pywinpty/pull/199) - add support for arm64 compilation, by [@nsait-linaro](https://github.com/nsait-linaro)
* [PR 198](https://github.com/spyder-ide/pywinpty/pull/198) - enable building pywinpty without winpty and debug code, by [@nsait-linaro](https://github.com/nsait-linaro)
* [PR 196](https://github.com/spyder-ide/pywinpty/pull/196) - Update windows requirement from 0.21.1 to 0.26.0 in /findlib, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 194](https://github.com/spyder-ide/pywinpty/pull/194) - Update pyo3 requirement from 0.14.1 to 0.15.0, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 192](https://github.com/spyder-ide/pywinpty/pull/192) - Fix compile error C2664 on win32, by [@cgohlke](https://github.com/cgohlke)

In this release 5 pull requests were closed.


## Version 1.1.5 (2021/10/28)

### Issues Closed

* [Issue 190](https://github.com/spyder-ide/pywinpty/issues/190) - Release v1.1.5
* [Issue 185](https://github.com/spyder-ide/pywinpty/issues/185) - The wheel for Python 3.10 is not available ([PR 186](https://github.com/spyder-ide/pywinpty/pull/186) by [@joseph-roitman](https://github.com/joseph-roitman))

In this release 2 issues were closed.

### Pull Requests Merged

* [PR 186](https://github.com/spyder-ide/pywinpty/pull/186) - Build and publish with Python 3.10 in GitHub actions., by [@joseph-roitman](https://github.com/joseph-roitman) ([185](https://github.com/spyder-ide/pywinpty/issues/185))
* [PR 182](https://github.com/spyder-ide/pywinpty/pull/182) - Update windows requirement from 0.20.1 to 0.21.1 in /findlib, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 180](https://github.com/spyder-ide/pywinpty/pull/180) - Update windows requirement from 0.19.0 to 0.20.1 in /findlib, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 172](https://github.com/spyder-ide/pywinpty/pull/172) - Update windows requirement from 0.13.0 to 0.17.0 in /findlib, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 170](https://github.com/spyder-ide/pywinpty/pull/170) - Update pyo3 requirement from 0.13.2 to 0.14.1, by [@dependabot[bot]](https://github.com/apps/dependabot)

In this release 5 pull requests were closed.


## Version 1.1.4 (2021-07-08)

### Issues Closed

* [Issue 176](https://github.com/spyder-ide/pywinpty/issues/176) - Release v1.1.4

In this release 1 issue was closed.

### Pull Requests Merged

* [PR 175](https://github.com/spyder-ide/pywinpty/pull/175) - PR: Pin maturin version to v0.11.3, by [@andfoy](https://github.com/andfoy)
* [PR 174](https://github.com/spyder-ide/pywinpty/pull/174) - Update windows requirement from 0.17.0 to 0.19.0 in /findlib, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 169](https://github.com/spyder-ide/pywinpty/pull/169) - PR: Define project.name attribute in pyproject.toml, by [@andfoy](https://github.com/andfoy)
* [PR 168](https://github.com/spyder-ide/pywinpty/pull/168) - Update windows requirement from 0.12.0 to 0.13.0 in /findlib, by [@dependabot[bot]](https://github.com/apps/dependabot)

In this release 4 pull requests were closed.


## Version 1.1.3 (2021/06/24)

### Issues Closed

* [Issue 167](https://github.com/spyder-ide/pywinpty/issues/167) - Release v1.1.3
* [Issue 163](https://github.com/spyder-ide/pywinpty/issues/163) - Fix ConPTY stderr redirection ([PR 164](https://github.com/spyder-ide/pywinpty/pull/164) by [@andfoy](https://github.com/andfoy))

In this release 2 issues were closed.

### Pull Requests Merged

* [PR 166](https://github.com/spyder-ide/pywinpty/pull/166) - PR: Pin maturin version in pyproject.toml, by [@andfoy](https://github.com/andfoy)
* [PR 165](https://github.com/spyder-ide/pywinpty/pull/165) - PR: Fix ConPTY when pywinpty runs behind a GUI application, by [@andfoy](https://github.com/andfoy)
* [PR 164](https://github.com/spyder-ide/pywinpty/pull/164) - PR: Redirect stderr to stdout in ConPTY, by [@andfoy](https://github.com/andfoy) ([163](https://github.com/spyder-ide/pywinpty/issues/163))
* [PR 162](https://github.com/spyder-ide/pywinpty/pull/162) - Update windows requirement from 0.11.0 to 0.12.0 in /findlib, by [@dependabot[bot]](https://github.com/apps/dependabot)

In this release 4 pull requests were closed.


## Version 1.1.2 (2021/06/10)

### Issues Closed

* [Issue 160](https://github.com/spyder-ide/pywinpty/issues/160) - Release v1.1.2
* [Issue 157](https://github.com/spyder-ide/pywinpty/issues/157) - threading.Thread.setDaemon has been deprecated in favor of setting daemon attribute directly in Python 3.10 ([PR 158](https://github.com/spyder-ide/pywinpty/pull/158) by [@tirkarthi](https://github.com/tirkarthi))

In this release 2 issues were closed.

### Pull Requests Merged

* [PR 159](https://github.com/spyder-ide/pywinpty/pull/159) - PR: Update windows requirement from 0.10.0 to 0.11.0 in /findlib, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 158](https://github.com/spyder-ide/pywinpty/pull/158) - PR: Set daemon attribute instead of using setDaemon method that was deprecated in Python 3.10, by [@tirkarthi](https://github.com/tirkarthi) ([157](https://github.com/spyder-ide/pywinpty/issues/157))

In this release 2 pull requests were closed.


## Version 1.1.1 (2021/05/18)

### Issues Closed

* [Issue 155](https://github.com/spyder-ide/pywinpty/issues/155) - Release v1.1.1
* [Issue 153](https://github.com/spyder-ide/pywinpty/issues/153) - pywinpty on Pypi does not show supported Python versions or dependent packages ([PR 154](https://github.com/spyder-ide/pywinpty/pull/154) by [@andfoy](https://github.com/andfoy))

In this release 2 issues were closed.

### Pull Requests Merged

* [PR 154](https://github.com/spyder-ide/pywinpty/pull/154) - PR: Add requires-python to Cargo.toml, by [@andfoy](https://github.com/andfoy) ([153](https://github.com/spyder-ide/pywinpty/issues/153))

In this release 1 pull request was closed.


## Version 1.1.0 (2021/05/17)

### Issues Closed

* [Issue 152](https://github.com/spyder-ide/pywinpty/issues/152) - Release v1.1.0

In this release 1 issue was closed.

### Pull Requests Merged

* [PR 151](https://github.com/spyder-ide/pywinpty/pull/151) - Update windows requirement from 0.8.0 to 0.10.0 in /findlib, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 150](https://github.com/spyder-ide/pywinpty/pull/150) - PR: Enable dependabot updates, by [@andfoy](https://github.com/andfoy)
* [PR 149](https://github.com/spyder-ide/pywinpty/pull/149) - PR: Improve EOF detection when the pipes are not automatically closed, by [@andfoy](https://github.com/andfoy)

In this release 3 pull requests were closed.


## Version 1.0.1 (2021/04/27)

### Issues Closed

* [Issue 145](https://github.com/spyder-ide/pywinpty/issues/145) - Release v1.0.1
* [Issue 143](https://github.com/spyder-ide/pywinpty/issues/143) - Pip attempts to install pywinpty on Python 2.7 ([PR 144](https://github.com/spyder-ide/pywinpty/pull/144) by [@andfoy](https://github.com/andfoy))

In this release 2 issues were closed.

### Pull Requests Merged

* [PR 144](https://github.com/spyder-ide/pywinpty/pull/144) - PR: Add requires-python key in pyproject.toml, by [@andfoy](https://github.com/andfoy) ([143](https://github.com/spyder-ide/pywinpty/issues/143))

In this release 1 pull request was closed.


## Version 1.0.0 (2021/04/26)

### Issues Closed

* [Issue 141](https://github.com/spyder-ide/pywinpty/issues/141) - Update RELEASE instructions and add release github actions ([PR 142](https://github.com/spyder-ide/pywinpty/pull/142) by [@andfoy](https://github.com/andfoy))
* [Issue 140](https://github.com/spyder-ide/pywinpty/issues/140) - Release v1.0.0
* [Issue 138](https://github.com/spyder-ide/pywinpty/issues/138) - Update Readme ([PR 139](https://github.com/spyder-ide/pywinpty/pull/139) by [@andfoy](https://github.com/andfoy))
* [Issue 136](https://github.com/spyder-ide/pywinpty/issues/136) - Update CIs to use Github Actions ([PR 137](https://github.com/spyder-ide/pywinpty/pull/137) by [@andfoy](https://github.com/andfoy))
* [Issue 134](https://github.com/spyder-ide/pywinpty/issues/134) - Will it provide Python 3.9 version support? ([PR 137](https://github.com/spyder-ide/pywinpty/pull/137) by [@andfoy](https://github.com/andfoy))
* [Issue 133](https://github.com/spyder-ide/pywinpty/issues/133) - MNT: Stop using ci-helpers in appveyor.yml ([PR 137](https://github.com/spyder-ide/pywinpty/pull/137) by [@andfoy](https://github.com/andfoy))
* [Issue 122](https://github.com/spyder-ide/pywinpty/issues/122) - Support ConPTY on Windows 10 ([PR 137](https://github.com/spyder-ide/pywinpty/pull/137) by [@andfoy](https://github.com/andfoy))
* [Issue 121](https://github.com/spyder-ide/pywinpty/issues/121) - Expose winpty conerr pipe ([PR 137](https://github.com/spyder-ide/pywinpty/pull/137) by [@andfoy](https://github.com/andfoy))

In this release 8 issues were closed.

### Pull Requests Merged

* [PR 142](https://github.com/spyder-ide/pywinpty/pull/142) - PR: Update release instructions and add release workflows in github actions, by [@andfoy](https://github.com/andfoy) ([141](https://github.com/spyder-ide/pywinpty/issues/141))
* [PR 139](https://github.com/spyder-ide/pywinpty/pull/139) - PR: Update README and instructions, by [@andfoy](https://github.com/andfoy) ([138](https://github.com/spyder-ide/pywinpty/issues/138))
* [PR 137](https://github.com/spyder-ide/pywinpty/pull/137) - PR: Add support for ConPTY and Python 3.9 , by [@andfoy](https://github.com/andfoy) ([136](https://github.com/spyder-ide/pywinpty/issues/136), [134](https://github.com/spyder-ide/pywinpty/issues/134), [133](https://github.com/spyder-ide/pywinpty/issues/133), [133](https://github.com/spyder-ide/pywinpty/issues/133), [131](https://github.com/spyder-ide/pywinpty/issues/131), [122](https://github.com/spyder-ide/pywinpty/issues/122), [121](https://github.com/spyder-ide/pywinpty/issues/121))

In this release 3 pull requests were closed.


## Version 0.5.7 (2019/11/26)

### Issues Closed

* [Issue 128](https://github.com/spyder-ide/pywinpty/issues/128) - Release v0.5.7

In this release 1 issue was closed.

### Pull Requests Merged

* [PR 127](https://github.com/spyder-ide/pywinpty/pull/127) - PR: Debug Python 3.8 wheel building

In this release 1 pull request was closed.


## Version 0.5.6 (2019/11/26)

### Issues Closed

* [Issue 126](https://github.com/spyder-ide/pywinpty/issues/126) - Release v0.5.6
* [Issue 123](https://github.com/spyder-ide/pywinpty/issues/123) - pip install fails on Python 3.8/Windows ([PR 125](https://github.com/spyder-ide/pywinpty/pull/125))

In this release 2 issues were closed.

### Pull Requests Merged

* [PR 125](https://github.com/spyder-ide/pywinpty/pull/125) - PR: Add support for Python 3.8 ([123](https://github.com/spyder-ide/pywinpty/issues/123))

In this release 1 pull request was closed.


## Version 0.5.5 (2018/12/09)

### Issues Closed

* [Issue 120](https://github.com/spyder-ide/pywinpty/issues/120) - Release v0.5.5
* [Issue 118](https://github.com/spyder-ide/pywinpty/issues/118) - pip install fails on 3.7, prevents Jupyter install ([PR 119](https://github.com/spyder-ide/pywinpty/pull/119))
* [Issue 116](https://github.com/spyder-ide/pywinpty/issues/116) - Python 3.7 wheels? ([PR 119](https://github.com/spyder-ide/pywinpty/pull/119))

In this release 3 issues were closed.

### Pull Requests Merged

* [PR 119](https://github.com/spyder-ide/pywinpty/pull/119) - PR: Add support for Python 3.7 ([118](https://github.com/spyder-ide/pywinpty/issues/118), [116](https://github.com/spyder-ide/pywinpty/issues/116))
* [PR 115](https://github.com/spyder-ide/pywinpty/pull/115) - PR: Update readme to remove funding appeal, harmonize with other readmes and minor fixes

In this release 2 pull requests were closed.

## Version 0.5.4 (2018/06/07)

### Issues Closed

* [Issue 114](https://github.com/spyder-ide/pywinpty/issues/114) - Release v0.5.4
* [Issue 111](https://github.com/spyder-ide/pywinpty/issues/111) - Remove validation at import introduced in 0.5.2 ([PR 112](https://github.com/spyder-ide/pywinpty/pull/112))
* [Issue 110](https://github.com/spyder-ide/pywinpty/issues/110) - Disable ptyprocess blocking read by means of a environment variable ([PR 113](https://github.com/spyder-ide/pywinpty/pull/113))
* [Issue 108](https://github.com/spyder-ide/pywinpty/issues/108) - Access violation once again ([PR 109](https://github.com/spyder-ide/pywinpty/pull/109))

In this release 4 issues were closed.

### Pull Requests Merged

* [PR 113](https://github.com/spyder-ide/pywinpty/pull/113) - PR: Add PYWINPTY_BLOCK environment variable to disable ptyprocess read block ([110](https://github.com/spyder-ide/pywinpty/issues/110))
* [PR 112](https://github.com/spyder-ide/pywinpty/pull/112) - PR: Remove import-time verification ([111](https://github.com/spyder-ide/pywinpty/issues/111))
* [PR 109](https://github.com/spyder-ide/pywinpty/pull/109) - PR: Fix for access violation error ([108](https://github.com/spyder-ide/pywinpty/issues/108))

In this release 3 pull requests were closed.


## Version 0.5.3 (2018/05/25)

### Issues Closed

* [Issue 107](https://github.com/spyder-ide/pywinpty/issues/107) - Release 0.5.3
* [Issue 105](https://github.com/spyder-ide/pywinpty/issues/105) - 0.5.2 wheels seem to be missing some DLLs ([PR 106](https://github.com/spyder-ide/pywinpty/pull/106))

In this release 2 issues were closed.

### Pull Requests Merged

* [PR 106](https://github.com/spyder-ide/pywinpty/pull/106) - PR: Bundle libgcc and libwinpthread DLL libraries alongside wheels ([105](https://github.com/spyder-ide/pywinpty/issues/105))

In this release 1 pull request was closed.

## Version 0.5.2 (2018/05/23)

### Issues Closed

* [Issue 102](https://github.com/spyder-ide/pywinpty/issues/102) - Release v0.5.2
* [Issue 101](https://github.com/spyder-ide/pywinpty/issues/101) - Update Readme according to latest changes ([PR 104](https://github.com/spyder-ide/pywinpty/pull/104))
* [Issue 96](https://github.com/spyder-ide/pywinpty/issues/96) - Fix CI Build ([PR 97](https://github.com/spyder-ide/pywinpty/pull/97))
* [Issue 59](https://github.com/spyder-ide/pywinpty/issues/59) - Access violation writing 0x0000000000000000 on Windows 7 ([PR 99](https://github.com/spyder-ide/pywinpty/pull/99))

In this release 4 issues were closed.

### Pull Requests Merged

* [PR 104](https://github.com/spyder-ide/pywinpty/pull/104) - PR: Update source compilation instructions ([101](https://github.com/spyder-ide/pywinpty/issues/101))
* [PR 103](https://github.com/spyder-ide/pywinpty/pull/103) - PR: Remove leftover file from merge
* [PR 100](https://github.com/spyder-ide/pywinpty/pull/100) - PR: Use conda defaults channel for testing
* [PR 99](https://github.com/spyder-ide/pywinpty/pull/99) - PR: Check that the library works at import time ([59](https://github.com/spyder-ide/pywinpty/issues/59))
* [PR 98](https://github.com/spyder-ide/pywinpty/pull/98) - Track code coverage using codecov
* [PR 97](https://github.com/spyder-ide/pywinpty/pull/97) - PR: Compile winpty on Appveyor using MinGW ([96](https://github.com/spyder-ide/pywinpty/issues/96))
* [PR 95](https://github.com/spyder-ide/pywinpty/pull/95) - PR: Wait (blocking) for data when using PtyProcess
* [PR 88](https://github.com/spyder-ide/pywinpty/pull/88) - PR: Fix OSError on spawning of PtyProcess ([86](https://github.com/spyder-ide/pywinpty/issues/86))

In this release 8 pull requests were closed.

## Version 0.5.1 (2017/12/01)

### Issues Closed

* [Issue 83](https://github.com/spyder-ide/pywinpty/issues/83) - Release 0.5.1
* [Issue 81](https://github.com/spyder-ide/pywinpty/issues/81) - Update instructions to build from source for Python 2
* [Issue 77](https://github.com/spyder-ide/pywinpty/issues/77) - Why is the tarball so huge?

In this release 3 issues were closed.

### Pull Requests Merged

* [PR 82](https://github.com/spyder-ide/pywinpty/pull/82) - PR: Add Python 2.7 build notes
* [PR 80](https://github.com/spyder-ide/pywinpty/pull/80) - Add trove classifier and note about VS Runtime
* [PR 78](https://github.com/spyder-ide/pywinpty/pull/78) - PR: Do not include binaries in the tarball

In this release 3 pull requests were closed.


## Version 0.5 (2017/11/27)

### Issues Closed

* [Issue 76](https://github.com/spyder-ide/pywinpty/issues/76) - Release 0.5
* [Issue 75](https://github.com/spyder-ide/pywinpty/issues/75) - Python 2.7 Support?

In this release 2 issues were closed.

### Pull Requests Merged

* [PR 66](https://github.com/spyder-ide/pywinpty/pull/66) - PR: Add Python 2 support

In this release 1 pull request was closed.


## Version 0.4.1 (2017/11/23)

### Issues Closed

* [Issue 73](https://github.com/spyder-ide/pywinpty/issues/73) - Copy winpty binaries on Appveyor upload
* [Issue 72](https://github.com/spyder-ide/pywinpty/issues/72) - Release 0.4.1

In this release 2 issues were closed.

### Pull Requests Merged

* [PR 74](https://github.com/spyder-ide/pywinpty/pull/74) - Add winpty binaries to Appveyor uploaded wheels

In this release 1 pull request was closed.



## Version 0.4 (2017/11/20)

### Issues Closed

* [Issue 71](https://github.com/spyder-ide/pywinpty/issues/71) - Release 0.4
* [Issue 68](https://github.com/spyder-ide/pywinpty/issues/68) - Enable automatic wheel distribution using AppVeyor

In this release 2 issues were closed.

### Pull Requests Merged

* [PR 70](https://github.com/spyder-ide/pywinpty/pull/70) - PR: Omit init file from coverage and fix Readme coverage badge
* [PR 69](https://github.com/spyder-ide/pywinpty/pull/69) - PR: Enable AppVeyor automatic wheel builds
* [PR 67](https://github.com/spyder-ide/pywinpty/pull/67) - PR: PtyProcess Cleanup
* [PR 65](https://github.com/spyder-ide/pywinpty/pull/65) - Add a file descriptor

In this release 4 pull requests were closed.


## Version 0.3 (2017/11/18)

### Issues Closed

* [Issue 63](https://github.com/spyder-ide/pywinpty/issues/63) - Implement a process wrapper
* [Issue 59](https://github.com/spyder-ide/pywinpty/issues/59) - Access violation writing 0x0000000000000000

In this release 2 issues were closed.

### Pull Requests Merged

* [PR 62](https://github.com/spyder-ide/pywinpty/pull/62) - Implement a PtyProcess class
* [PR 61](https://github.com/spyder-ide/pywinpty/pull/61) - PR: Define explicit calls to ReadFile and WriteFile

In this release 2 pull requests were closed.


## Version 0.2.1 (2017/08/23)

### Issues Closed

* [Issue 58](https://github.com/spyder-ide/pywinpty/issues/58) - Release v0.2.1
* [Issue 56](https://github.com/spyder-ide/pywinpty/issues/56) - Each call to isalive function cause to escape unwanted characters on output pipe
* [Issue 55](https://github.com/spyder-ide/pywinpty/issues/55) - isalive returns True if the underlying winpty process is dead, False otherwise

In this release 3 issues were closed.

### Pull Requests Merged

* [PR 57](https://github.com/spyder-ide/pywinpty/pull/57) - PR: Fix several cytpes migration issues

In this release 1 pull request was closed.


## Version 0.2.0 (2017/08/22)

### Issues Closed

* [Issue 54](https://github.com/spyder-ide/pywinpty/issues/54) - Release 0.2
* [Issue 52](https://github.com/spyder-ide/pywinpty/issues/52) - remove  'pypiwin32' from setup requirements

In this release 2 issues were closed.

### Pull Requests Merged

* [PR 53](https://github.com/spyder-ide/pywinpty/pull/53) - PR: Replace pywin32 function calls by Win32 ctypes calls

In this release 1 pull request was closed.

## Version 0.1.4 (2017/08/08)

### Issues Closed

* [Issue 50](https://github.com/spyder-ide/pywinpty/issues/50) - Release v0.1.4
* [Issue 47](https://github.com/spyder-ide/pywinpty/issues/47) - Include pypiwin32 dependency using an env variable
* [Issue 46](https://github.com/spyder-ide/pywinpty/issues/46) - Check if terminal dimensions are positive integers

In this release 3 issues were closed.

### Pull Requests Merged

* [PR 49](https://github.com/spyder-ide/pywinpty/pull/49) - Include pypiwin32 dependency only if PYWINPTY_WHL environment variable is present
* [PR 48](https://github.com/spyder-ide/pywinpty/pull/48) - Check if size/resize dimensions are non-negative/zero

In this release 2 pull requests were closed.


## Version 0.1.3 (2017/07/20)

### Issues Closed

* [Issue 43](https://github.com/spyder-ide/pywinpty/issues/43) - Bundle winpty binaries with Python wheels

In this release 1 issue was closed.

### Pull Requests Merged

* [PR 44](https://github.com/spyder-ide/pywinpty/pull/44) - PR: Update RELEASE.md file to mention winpty binaries inclusion before creating our wheels

In this release 1 pull request was closed.


## Version 0.1.2 (2017/07/15)

### Issues Closed

* [Issue 41](https://github.com/spyder-ide/pywinpty/issues/41) - Release 0.1.2
* [Issue 35](https://github.com/spyder-ide/pywinpty/issues/35) - Add a RELEASE.md
* [Issue 34](https://github.com/spyder-ide/pywinpty/issues/34) - Add a CHANGELOG.md
* [Issue 33](https://github.com/spyder-ide/pywinpty/issues/33) - Get to know if a process is alive or not
* [Issue 30](https://github.com/spyder-ide/pywinpty/issues/30) - Improve external build documentation

In this release 5 issues were closed.

### Pull Requests Merged

* [PR 40](https://github.com/spyder-ide/pywinpty/pull/40) - PR: Improve README building from source section
* [PR 39](https://github.com/spyder-ide/pywinpty/pull/39) - PR: Add release instructions
* [PR 38](https://github.com/spyder-ide/pywinpty/pull/38) - PR: Check if a process is alive

In this release 3 pull requests were closed.


## Version 0.1.1 (2017-07-15)

### Issues Closed

* [Issue 36](https://github.com/spyder-ide/pywinpty/issues/36) - Release v0.1.1
* [Issue 32](https://github.com/spyder-ide/pywinpty/issues/32) - Add code autoformatter
* [Issue 27](https://github.com/spyder-ide/pywinpty/issues/27) - Update README usage documentation
* [Issue 22](https://github.com/spyder-ide/pywinpty/issues/22) - Add basic tests
* [Issue 21](https://github.com/spyder-ide/pywinpty/issues/21) - add .txt to LICENSE to be windows friendly
* [Issue 20](https://github.com/spyder-ide/pywinpty/issues/20) - Add LICENSE to Manifest.in
* [Issue 4](https://github.com/spyder-ide/pywinpty/issues/4) - Add CI integration

In this release 7 issues were closed.

### Pull Requests Merged

* [PR 29](https://github.com/spyder-ide/pywinpty/pull/29) - PR: Add appveyor CI integration
* [PR 28](https://github.com/spyder-ide/pywinpty/pull/28) - PR: Update README usage documentation
* [PR 26](https://github.com/spyder-ide/pywinpty/pull/26) - PR: Add LICENSE.txt to MANIFEST.in file
* [PR 25](https://github.com/spyder-ide/pywinpty/pull/25) - PR: Add spawn process failure test
* [PR 24](https://github.com/spyder-ide/pywinpty/pull/24) - PR: Minor test corrections
* [PR 23](https://github.com/spyder-ide/pywinpty/pull/23) - PR: Basic tests addition

In this release 6 pull requests were closed.

## Version 0.1 (2017-06-23)

### Issues Closed

* [Issue 18](https://github.com/spyder-ide/pywinpty/issues/18) - Change package name to be pywinpty
* [Issue 15](https://github.com/spyder-ide/pywinpty/issues/15) - Update setup.py to discriminate between pywin32 and pypiwin32 dependencies
* [Issue 14](https://github.com/spyder-ide/pywinpty/issues/14) - Remove experimental features
* [Issue 12](https://github.com/spyder-ide/pywinpty/issues/12) - On conda environments, compile using conda-build defined variables
* [Issue 10](https://github.com/spyder-ide/pywinpty/issues/10) - Fix cursor and key sequence escapes
* [Issue 8](https://github.com/spyder-ide/pywinpty/issues/8) - Update README description
* [Issue 7](https://github.com/spyder-ide/pywinpty/issues/7) - Release as version 0.1.0
* [Issue 3](https://github.com/spyder-ide/pywinpty/issues/3) - Update setup.py , add version
* [Issue 2](https://github.com/spyder-ide/pywinpty/issues/2) - Add doctsrings

In this release 9 issues were closed.

### Pull Requests Merged

* [PR 19](https://github.com/spyder-ide/pywinpty/pull/19) - PR: Replace setup.py package name by pywinpty
* [PR 17](https://github.com/spyder-ide/pywinpty/pull/17) - PR: Add pypiwin32 dependency only if installing using pip
* [PR 16](https://github.com/spyder-ide/pywinpty/pull/16) - PR: Remove experimental features

In this release 3 pull requests were closed.
